==> tencentcloud-sdk-java-3.0.41-sources.jar: com/tencentcloudapi/cdn/v20180606/models/DescribeMapInfoRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cdn.v20180606.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeMapInfoRequest  extends AbstractModel{

    /**
    * 映射查询类别：
ips：运营商映射查询
district：省份映射查询
    */
    @SerializedName("Name")
    @Expose
    private String Name;

    /**
     * 获取映射查询类别：
ips：运营商映射查询
district：省份映射查询
     * @return Name 映射查询类别：
ips：运营商映射查询
district：省份映射查询
     */
    public String getName() {
        return this.Name;
    }

    /**
     * 设置映射查询类别：
ips：运营商映射查询
district：省份映射查询
     * @param Name 映射查询类别：
ips：运营商映射查询
district：省份映射查询
     */
    public void setName(String Name) {
        this.Name = Name;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Name", this.Name);

    }
}

==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/cdn/v20180606/models/DescribeMapInfoRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cdn.v20180606.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeMapInfoRequest  extends AbstractModel{

    /**
    * 映射查询类别：
isp：运营商映射查询
district：省份映射查询
    */
    @SerializedName("Name")
    @Expose
    private String Name;

    /**
     * 获取映射查询类别：
isp：运营商映射查询
district：省份映射查询
     * @return Name 映射查询类别：
isp：运营商映射查询
district：省份映射查询
     */
    public String getName() {
        return this.Name;
    }

    /**
     * 设置映射查询类别：
isp：运营商映射查询
district：省份映射查询
     * @param Name 映射查询类别：
isp：运营商映射查询
district：省份映射查询
     */
    public void setName(String Name) {
        this.Name = Name;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Name", this.Name);

    }
}
